package com.psbc.cpsp.eden.common.context;

/**
 * 用户上下文
 * 
 * 用于存储当前用户的信息
 */
public class UserContext {
    private static final ThreadLocal<String> userIdHolder = new ThreadLocal<>();
    private static final ThreadLocal<String> tenantIdHolder = new ThreadLocal<>();

    /**
     * 设置用户ID
     * 
     * @param userId 用户ID
     */
    public static void setUserId(String userId) {
        userIdHolder.set(userId);
    }

    /**
     * 获取用户ID
     * 
     * @return 用户ID
     */
    public static String getUserId() {
        String userId = userIdHolder.get();
        if (userId == null || userId.isEmpty()) {
            return "system";
        }
        return userId;
    }

    /**
     * 设置租户ID
     * 
     * @param tenantId 租户ID
     */
    public static void setTenantId(String tenantId) {
        tenantIdHolder.set(tenantId);
    }

    /**
     * 获取租户ID
     * 
     * @return 租户ID
     */
    public static String getTenantId() {
        String tenantId = tenantIdHolder.get();
        if (tenantId == null || tenantId.isEmpty()) {
            return "1";
        }
        return tenantId;
    }

    /**
     * 清除当前线程的用户上下文
     */
    public static void clear() {
        userIdHolder.remove();
        tenantIdHolder.remove();
    }
}