package com.psbc.cpsp.eden.common.entity;

import com.baomidou.mybatisplus.annotation.*;
import com.fasterxml.jackson.annotation.JsonFormat;
import com.psbc.cpsp.entity.BaseEntity;
import lombok.Data;
import lombok.EqualsAndHashCode;

import javax.validation.constraints.NotBlank;
import javax.validation.constraints.NotNull;
import javax.validation.constraints.Size;
import java.math.BigDecimal;
import java.util.Date;

/**
 * 资产实体类
 */
@Data
@EqualsAndHashCode(callSuper = true)
@TableName("tb_asset")
public class Asset extends BaseEntity {
    private static final long serialVersionUID = 1L;

    /** 资产ID */
    @TableId(type = IdType.AUTO)
    private Long id;

    /** 资产编码 */
    @NotBlank(message = "资产编码不能为空")
    @Size(max = 100, message = "资产编码长度不能超过100个字符")
    private String assetCode;

    /** 资产名称 */
    @NotBlank(message = "资产名称不能为空")
    @Size(max = 200, message = "资产名称长度不能超过200个字符")
    private String assetName;

    /** 资产分类ID */
    @NotNull(message = "资产分类不能为空")
    private Long classificationId;

    /** 管理员ID */
    private String adminUserId;

    /** 所属公司ID */
    @NotNull(message = "所属公司不能为空")
    private Long companyId;

    /** 所在位置ID */
    @NotNull(message = "所在位置不能为空")
    private Long locationId;

    /** 购置方式 采购/租赁 */
    @NotBlank(message = "购置方式不能为空")
    @Size(max = 20, message = "购置方式长度不能超过20个字符")
    private String purchaseType;

    /** 品牌 */
    @NotBlank(message = "品牌不能为空")
    @Size(max = 100, message = "品牌长度不能超过100个字符")
    private String brand;

    /** 型号 */
    @Size(max = 100, message = "型号长度不能超过100个字符")
    private String model;

    /** 设备序列号 */
    @Size(max = 100, message = "设备序列号长度不能超过100个字符")
    private String serialNumber;

    /** 购置金额 */
    private BigDecimal purchaseAmount;

    /** 预计使用期限(月) */
    private Integer expectedUsefulLife;

    /** 备注 */
    private String remark;

    /** 购置时间 */
    @JsonFormat(pattern = "yyyy-MM-dd", timezone = "GMT+8")
    private Date purchaseDate;

    /** 入库时间 */
    @JsonFormat(pattern = "yyyy-MM-dd", timezone = "GMT+8")
    private Date storageDate;

    /** 资产照片URL */
    @Size(max = 500, message = "资产照片URL长度不能超过500个字符")
    private String assetPhoto;

    /** 保养到期时间 */
    @JsonFormat(pattern = "yyyy-MM-dd", timezone = "GMT+8")
    private Date maintenanceDueDate;

    /** 保养说明 */
    private String maintenanceDescription;

    /** 预计折旧期限(月) */
    private Integer expectedDepreciationPeriod;

    /** 资产状态 空闲/在用/借用/派发中/退库中/借出中/归还中/维修中 */
    private String assetStatus;

    /** 保养是否到期筛选 1-已到期 0-未到期 */
    private String maintenanceExpired;

    /** 是否删除 0-未删除 1-已删除 */
    @TableLogic
    @TableField(fill = FieldFill.INSERT)
    private String delFlag;
}