package com.psbc.cpsp.eden.common.entity;

import com.baomidou.mybatisplus.annotation.IdType;
import com.baomidou.mybatisplus.annotation.TableId;
import com.baomidou.mybatisplus.annotation.TableName;
import com.baomidou.mybatisplus.annotation.TableField;
import com.baomidou.mybatisplus.annotation.TableLogic;
import com.baomidou.mybatisplus.annotation.FieldFill;
import com.psbc.cpsp.entity.BaseEntity;
import lombok.Data;
import lombok.EqualsAndHashCode;
import javax.validation.constraints.NotBlank;
import javax.validation.constraints.Size;
import javax.validation.constraints.Pattern;

/**
 * 资产标签实体类
 */
@Data
@EqualsAndHashCode(callSuper = true)
@TableName("tb_asset_label")
public class AssetLabel extends BaseEntity {
    private static final long serialVersionUID = 1L;

    /** 标签ID */
    @TableId(type = IdType.AUTO)
    private Long id;

    /** 模板类型 1-模板1 2-模板2 3-模板3 4-模板4，数值代表最多可选择的标签数量 */
    @NotBlank(message = "模板类型不能为空")
    @Size(max = 1, message = "模板类型长度为1个字符")
    @Pattern(regexp = "[1-4]", message = "模板类型必须是1-4之间的数字")
    private String templateType;

    /**
     * 标签集合(以逗号分隔的数字):
     * 1-资产名称,2-资产分类,3-资产编码,4-资产位置,5-品牌,6-型号,7-设备序列号,8-管理员,9-保养到期时间,10-保养说明,11-使用部门
     */
    private String labelItems;

    /** 纸张类型 1-标签专用纸 2-A4(2列标签) 3-A4(3列标签) */
    // @NotBlank(message = "纸张类型不能为空")
    @Size(max = 1, message = "纸张类型长度为1个字符")
    @Pattern(regexp = "[1-3]", message = "纸张类型必须是1-3之间的数字")
    private String paperType;

    /** 标签宽度(mm)，仅当纸张类型为标签专用纸时有效 */
    @Size(max = 8, message = "标签宽度不能超过8个字符")
    // @Pattern(regexp = "^[1-9]\\d*$", message = "标签宽度必须是正整数")
    private String labelWidth;

    /** 标签高度(mm)，仅当纸张类型为标签专用纸时有效 */
    @Size(max = 8, message = "标签高度不能超过8个字符")
    // @Pattern(regexp = "^[1-9]\\d*$", message = "标签高度必须是正整数")
    private String labelHeight;

    /** 是否删除 0-未删除 1-已删除 */
    @TableLogic
    @TableField(fill = FieldFill.INSERT)
    private String delFlag;
}