package com.psbc.cpsp.eden.common.interceptor;

import com.psbc.cpsp.eden.common.context.UserContext;
import org.springframework.web.servlet.HandlerInterceptor;
import javax.servlet.http.HttpServletRequest;
import javax.servlet.http.HttpServletResponse;

/**
 * 租户拦截器
 */
public class TenantInterceptor implements HandlerInterceptor {

    // 固定租户ID
    private static final String FIXED_TENANT_ID = "1";
    // 默认用户ID
    private static final String DEFAULT_USER_ID = "admin";

    @Override
    public boolean preHandle(HttpServletRequest request, HttpServletResponse response, Object handler) {
        // 获取用户ID，如果没有则使用默认值
        String userId = request.getHeader("X-User-ID");

        if (userId == null || userId.isEmpty()) {
            userId = DEFAULT_USER_ID;
        }

        // 设置到ThreadLocal中，租户ID统一使用固定值"1"
        UserContext.setTenantId(FIXED_TENANT_ID);
        UserContext.setUserId(userId);

        return true;
    }

    @Override
    public void afterCompletion(HttpServletRequest request, HttpServletResponse response, Object handler,
            Exception ex) {
        // 清理ThreadLocal
        UserContext.clear();
    }
}