package com.psbc.cpsp.eden.common.response;

import lombok.Data;

/**
 * 统一响应结果类
 * 
 * @author eden
 */
@Data
public class AssetResult<T> {
    /**
     * 响应码
     */
    private String code;

    /**
     * 响应消息
     */
    private String message;

    /**
     * 响应数据
     */
    private T data;

    public AssetResult(String code, String message, T data) {
        this.code = code;
        this.message = message;
        this.data = data;
    }

    /**
     * 返回成功消息
     * 
     * @param data 数据对象
     * @return 成功消息
     */
    public static <T> AssetResult<T> success(T data) {
        return new AssetResult<>("0000000000000000", "操作成功", data);
    }

    /**
     * 返回成功消息
     * 
     * @return 成功消息
     */
    public static <T> AssetResult<T> success() {
        return new AssetResult<>("0000000000000000", "操作成功", null);
    }

    /**
     * 返回错误消息
     * 
     * @param message 错误消息
     * @return 错误消息
     */
    public static <T> AssetResult<T> error(String message) {
        return new AssetResult<>("999999", message, null);
    }

    /**
     * 返回错误消息
     * 
     * @param code    错误码
     * @param message 错误消息
     * @return 错误消息
     */
    public static <T> AssetResult<T> error(String code, String message) {
        return new AssetResult<>(code, message, null);
    }

    public boolean isSuccess() {
        return "0000000000000000".equals(code);
    }
}