package com.psbc.cpsp.eden.common.utils;

import lombok.extern.slf4j.Slf4j;
import org.springframework.stereotype.Component;

import javax.annotation.PostConstruct;
import java.util.Collections;
import java.util.HashMap;
import java.util.Map;

/**
 * 管理员用户缓存工具类
 * 用于存储管理员ID和姓名的映射关系
 */
@Slf4j
@Component
public class AdminUserCache {

    /**
     * 管理员ID和姓名的映射关系
     * key: 管理员ID, value: 管理员姓名
     */
    private static final Map<String, String> ADMIN_USERS = new HashMap<>();

    /**
     * 初始化管理员数据
     */
    @PostConstruct
    public void init() {
        log.info("初始化管理员数据...");

        // 添加管理员数据
        ADMIN_USERS.put("1", "张三");
        ADMIN_USERS.put("2", "李四");
        ADMIN_USERS.put("3", "王五");
        ADMIN_USERS.put("4", "赵六");
        ADMIN_USERS.put("7", "钱七");

        log.info("管理员数据初始化完成，共 {} 条记录", ADMIN_USERS.size());
    }

    /**
     * 获取管理员姓名
     *
     * @param adminUserId 管理员ID
     * @return 管理员姓名，如果不存在则返回未知管理员
     */
    public static String getAdminUserName(String adminUserId) {
        if (adminUserId == null || adminUserId.isEmpty()) {
            return "未知管理员";
        }
        return ADMIN_USERS.getOrDefault(adminUserId, "未知管理员(" + adminUserId + ")");
    }

    /**
     * 获取所有管理员数据
     *
     * @return 管理员ID和姓名的映射关系
     */
    public static Map<String, String> getAllAdminUsers() {
        return Collections.unmodifiableMap(ADMIN_USERS);
    }

    /**
     * 判断管理员ID是否存在
     *
     * @param adminUserId 管理员ID
     * @return 是否存在
     */
    public static boolean exists(String adminUserId) {
        return adminUserId != null && ADMIN_USERS.containsKey(adminUserId);
    }
}