package com.psbc.cpsp.eden.common.utils;

import lombok.extern.slf4j.Slf4j;
import org.springframework.stereotype.Component;

import javax.annotation.PostConstruct;
import java.util.Collections;
import java.util.HashMap;
import java.util.Map;

/**
 * 公司数据缓存工具类
 * 用于存储公司ID和公司名称的映射关系
 */
@Slf4j
@Component
public class CompanyCache {

    /**
     * 公司ID和名称的映射关系
     * key: 公司ID, value: 公司名称
     */
    private static final Map<String, String> COMPANIES = new HashMap<>();

    /**
     * 初始化公司数据
     */
    @PostConstruct
    public void init() {
        log.info("初始化公司数据...");

        // 添加公司数据
        COMPANIES.put("1", "总公司");
        COMPANIES.put("2", "北京分公司");
        COMPANIES.put("3", "上海分公司");
        COMPANIES.put("4", "广州分公司");
        COMPANIES.put("5", "深圳分公司");

        log.info("公司数据初始化完成，共 {} 条记录", COMPANIES.size());
    }

    /**
     * 获取公司名称
     *
     * @param companyId 公司ID
     * @return 公司名称，如果不存在则返回未知公司
     */
    public static String getCompanyName(Long companyId) {
        if (companyId == null) {
            return "未知公司";
        }
        return COMPANIES.getOrDefault(companyId, "未知公司(" + companyId + ")");
    }

    /**
     * 获取所有公司数据
     *
     * @return 公司ID和名称的映射关系
     */
    public static Map<String, String> getAllCompanies() {
        return Collections.unmodifiableMap(COMPANIES);
    }

    /**
     * 判断公司ID是否存在
     *
     * @param companyId 公司ID
     * @return 是否存在
     */
    public static boolean exists(Long companyId) {
        return companyId != null && COMPANIES.containsKey(companyId);
    }
}