package com.psbc.cpsp.eden.config;

import com.zaxxer.hikari.HikariDataSource;
import lombok.extern.slf4j.Slf4j;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.boot.autoconfigure.jdbc.DataSourceProperties;
import org.springframework.context.annotation.Bean;
import org.springframework.context.annotation.Configuration;
import org.springframework.context.annotation.Primary;

import javax.sql.DataSource;
import java.util.concurrent.ScheduledExecutorService;
import java.util.concurrent.ScheduledThreadPoolExecutor;
import java.util.concurrent.TimeUnit;

/**
 * 数据源配置类
 * 添加数据库连接池监控
 */
@Slf4j
@Configuration
public class DataSourceConfig {

    @Autowired
    private DataSourceProperties properties;

    /**
     * 数据源配置
     */
    @Bean
    @Primary
    public DataSource dataSource() {
        HikariDataSource dataSource = properties.initializeDataSourceBuilder()
                .type(HikariDataSource.class)
                .build();
        
        // 使用线程池定期打印连接池状态
        ScheduledExecutorService scheduledExecutorService = new ScheduledThreadPoolExecutor(1);
        scheduledExecutorService.scheduleAtFixedRate(() -> {
            log.info("HikariCP连接池状态 - 活动连接数: {}, 空闲连接数: {}, 总连接数: {}, 等待连接数: {}",
                    dataSource.getHikariPoolMXBean().getActiveConnections(),
                    dataSource.getHikariPoolMXBean().getIdleConnections(),
                    dataSource.getHikariPoolMXBean().getTotalConnections(),
                    dataSource.getHikariPoolMXBean().getThreadsAwaitingConnection());
        }, 60, 60, TimeUnit.SECONDS);
        
        return dataSource;
    }
} 