package com.psbc.cpsp.eden.config;

import com.baomidou.mybatisplus.core.handlers.MetaObjectHandler;
import com.psbc.cpsp.eden.enums.DelFlagEnum;
import lombok.extern.slf4j.Slf4j;
import org.apache.ibatis.reflection.MetaObject;
import org.springframework.stereotype.Component;

import java.util.Date;

/**
 * MyBatis-Plus自动填充处理器
 */
@Slf4j
@Component
public class MybatisPlusMetaObjectHandler implements MetaObjectHandler {

    // 固定的租户ID和用户ID
    private static final String FIXED_TENANT_ID = "1";
    private static final String FIXED_USER_ID = "admin";

    @Override
    public void insertFill(MetaObject metaObject) {
        log.debug("自动填充Insert字段");

        // 创建时间
        this.strictInsertFill(metaObject, "createTime", Date.class, new Date());

        // 创建人
        this.strictInsertFill(metaObject, "createUserId", String.class, FIXED_USER_ID);

        // 是否删除
        this.strictInsertFill(metaObject, "delFlag", String.class, DelFlagEnum.NORMAL.getCode());

        // 租户ID - 直接使用固定值
        this.strictInsertFill(metaObject, "tenantId", String.class, FIXED_TENANT_ID);

        // 最后修改时间
        this.strictInsertFill(metaObject, "lastModTime", Date.class, new Date());

        // 最后修改人
        this.strictInsertFill(metaObject, "lastModUserId", String.class, FIXED_USER_ID);
    }

    @Override
    public void updateFill(MetaObject metaObject) {
        log.debug("自动填充Update字段");

        // 最后修改时间
        this.strictUpdateFill(metaObject, "lastModTime", Date.class, new Date());

        // 最后修改人 - 直接使用固定值
        this.strictUpdateFill(metaObject, "lastModUserId", String.class, FIXED_USER_ID);
    }
}