package com.psbc.cpsp.eden.controller.asset;

import com.psbc.cpsp.entity.CpspReponse;
import com.psbc.cpsp.eden.common.entity.AssetLabel;
import com.psbc.cpsp.eden.service.asset.IAssetLabelService;
import lombok.extern.slf4j.Slf4j;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.validation.annotation.Validated;
import org.springframework.web.bind.annotation.*;

import java.util.Date;

/**
 * 资产标签Controller
 *
 * @author eden
 */
@Slf4j
@Validated
@RestController
@RequestMapping("/asset/label")
public class AssetLabelController {
    @Autowired
    private IAssetLabelService assetLabelService;

    /**
     * 查询资产标签列表
     * 每个租户只能有一条记录
     */
    @GetMapping("/list")
    public CpspReponse<AssetLabel> list() {
        log.info("查询资产标签列表");

        // 根据租户ID查询标签
        AssetLabel label = assetLabelService.selectByAll();
        if (label == null) {
            log.info("当前租户未配置资产标签,请前往配置");
        }

        return CpspReponse.ok(label);
    }

    /**
     * 新增资产标签
     * 每个租户只能有一条记录
     */
    @PostMapping("/create")
    public CpspReponse<AssetLabel> create(@Validated @RequestBody AssetLabel label) {
        log.info("新增资产标签, 参数: {}", label);

        // 验证标签数据
        try {
            assetLabelService.validateAssetLabel(label);
        } catch (Exception e) {
            return CpspReponse.error("999999", e.getMessage());
        }

        // 检查租户是否已有标签
        AssetLabel existingLabel = assetLabelService.selectByAll();
        if (existingLabel != null) {
            // 如果租户已存在标签，则更新标签信息
            label.setId(existingLabel.getId());
            label.setLastModUserId("system");
            label.setLastModTime(new Date());
            return CpspReponse.ok(assetLabelService.update(label));
        }

        // 设置默认值
        if (label.getCreateUserId() == null || label.getCreateUserId().isEmpty()) {
            label.setCreateUserId("system");
        }

        // 设置创建时间
        label.setCreateTime(new Date());
        return CpspReponse.ok(assetLabelService.insert(label));
    }

    /**
     * 修改资产标签
     * 根据当前租户ID修改标签
     */
    @PostMapping("/update")
    public CpspReponse<AssetLabel> update(@Validated @RequestBody AssetLabel label) {
        log.info("修改资产标签, 参数: {}", label);


        // 根据租户ID查询现有标签
        AssetLabel existingLabel = assetLabelService.selectByAll();
        if (existingLabel == null) {
            return CpspReponse.error("999999", "当前租户未配置资产标签");
        }

        // 验证标签数据
        try {
            assetLabelService.validateAssetLabel(label);
        } catch (Exception e) {
            return CpspReponse.error("999999", e.getMessage());
        }

        // 设置ID和租户ID
        label.setId(existingLabel.getId());

        // 设置修改人和修改时间
        label.setLastModUserId("system");
        label.setLastModTime(new Date());

        return CpspReponse.ok(assetLabelService.update(label));
    }
}