package com.psbc.cpsp.eden.enums;


import com.psbc.cpsp.eden.constants.AssetConstants;

/**
 * 购置方式枚举
 */
public enum PurchaseTypeEnum {

    /**
     * 采购
     */
    BUY(AssetConstants.PURCHASE_TYPE_BUY, AssetConstants.PURCHASE_TYPE_BUY_NAME),

    /**
     * 租赁
     */
    RENT(AssetConstants.PURCHASE_TYPE_RENT, AssetConstants.PURCHASE_TYPE_RENT_NAME);

    private final String code;
    private final String name;

    PurchaseTypeEnum(String code, String name) {
        this.code = code;
        this.name = name;
    }

    /**
     * 获取编码
     */
    public String getCode() {
        return code;
    }

    /**
     * 获取名称
     */
    public String getName() {
        return name;
    }

    /**
     * 根据编码获取枚举对象
     * 
     * @param code 编码
     * @return 枚举对象
     */
    public static PurchaseTypeEnum getByCode(String code) {
        for (PurchaseTypeEnum type : values()) {
            if (type.getCode().equals(code)) {
                return type;
            }
        }
        return null;
    }

    /**
     * 获取显示名称
     * 
     * @param code 编码
     * @return 显示名称
     */
    public static String getNameByCode(String code) {
        PurchaseTypeEnum type = getByCode(code);
        return type != null ? type.getName() : code;
    }

    /**
     * 校验编码是否有效
     * 
     * @param code 编码
     * @return 是否有效
     */
    public static boolean isValid(String code) {
        return getByCode(code) != null;
    }
}