package com.psbc.cpsp.eden.mapper.asset;

import com.psbc.cpsp.eden.common.entity.AssetLabel;
import org.apache.ibatis.annotations.Mapper;
import org.apache.ibatis.annotations.Param;
import java.util.List;

/**
 * 资产标签Mapper接口
 */
@Mapper
public interface AssetLabelMapper {
        /**
         * 新增资产标签
         *
         * @param label 资产标签信息
         * @return 影响行数
         */
        int insert(AssetLabel label);

        /**
         * 修改资产标签
         *
         * @param label 资产标签信息
         * @return 影响行数
         */
        int update(AssetLabel label);

        /**
         * 根据ID查询资产标签详情
         *
         * @param id       资产标签ID
         * @return 资产标签信息
         */
        AssetLabel selectById(@Param("id") Long id);

        /**
         * 根据条件查询资产标签列表
         * 
         * @param label 查询条件
         * @return 资产标签列表
         */
        List<AssetLabel> selectList(AssetLabel label);

        /**
         * 逻辑删除资产标签
         *
         * @param id            资产标签ID
         * @param lastModUserId 最后修改人ID
         * @return 影响行数
         */
        int deleteById(@Param("id") Long id, @Param("lastModUserId") String lastModUserId);

        /**
         * 批量逻辑删除资产标签
         *
         * @param ids           资产标签ID集合
         * @param lastModUserId 最后修改人ID
         * @return 影响行数
         */
        int deleteBatchIds(@Param("ids") List<Long> ids, @Param("lastModUserId") String lastModUserId);
}