package com.psbc.cpsp.eden.mapper.asset;

import com.psbc.cpsp.eden.common.entity.Asset;
import org.apache.ibatis.annotations.Mapper;
import org.apache.ibatis.annotations.Param;
import java.util.List;
import java.util.Date;

/**
 * 资产Mapper接口
 */
@Mapper
public interface AssetMapper {
        /**
         * 新增资产
         *
         * @param asset 资产信息
         * @return 影响行数
         */
        int insert(Asset asset);

        /**
         * 修改资产
         *
         * @param asset 资产信息
         * @return 影响行数
         */
        int update(Asset asset);

        /**
         * 更新资产状态
         *
         * @param id            资产ID
         * @param status        状态
         * @param lastModUserId 最后修改人ID
         * @param lastModTime   最后修改时间
         * @return 影响行数
         */
        int updateStatus(@Param("id") Long id, @Param("status") String status,
                        @Param("lastModUserId") String lastModUserId,
                        @Param("lastModTime") Date lastModTime);

        /**
         * 根据ID查询资产详情
         *
         * @param id       资产ID
         * @return 资产信息
         */
        Asset selectById(@Param("id") Long id);

        /**
         * 查询资产列表
         *
         * @param asset 资产信息
         * @return 资产集合
         */
        List<Asset> selectList(Asset asset);

        /**
         * 逻辑删除资产
         *
         * @param id            资产ID
         * @param lastModUserId 最后修改人ID
         * @return 影响行数
         */
        int deleteById(@Param("id") Long id, @Param("lastModUserId") String lastModUserId);

        /**
         * 批量逻辑删除资产
         *
         * @param ids           资产ID集合
         * @param lastModUserId 最后修改人ID
         * @return 影响行数
         */
        int deleteBatchIds(@Param("ids") List<Long> ids, @Param("lastModUserId") String lastModUserId);

        /**
         * 校验资产编码是否唯一
         *
         * @param assetCode 资产编码
         * @param id        资产ID
         * @return 结果
         */
        int checkCodeUnique(@Param("assetCode") String assetCode, @Param("id") Long id);

        /**
         * 根据资产编码查询资产信息
         *
         * @param assetCode 资产编码
         * @return 资产信息
         */
        Asset selectByCode(@Param("assetCode") String assetCode);

        /**
         * 获取指定前缀的最大序列号
         *
         * @param prefix 前缀
         * @return 最大序列号
         */
        int getMaxSequenceByPrefix(@Param("prefix") String prefix);
}