package com.psbc.cpsp.eden.service.asset;

import com.psbc.cpsp.eden.common.entity.AssetClassification;
import com.psbc.cpsp.eden.common.vo.TreeNode;
import java.util.List;

/**
 * 资产分类Service接口
 */
public interface IAssetClassificationService {
    /**
     * 查询资产分类列表
     *
     * @param classification 资产分类信息
     * @return 资产分类集合
     */
    List<AssetClassification> selectList(AssetClassification classification);

    /**
     * 查询资产分类树结构
     *
     * @param classification 资产分类信息
     * @return 树节点集合
     */
    List<TreeNode> selectTree(AssetClassification classification);

    /**
     * 根据父ID查询所有子节点
     *
     * @param parentId 父节点ID
     * @return 子节点集合
     */
    List<AssetClassification> selectChildrenByParentId(Long parentId);

    /**
     * 根据ID查询资产分类
     *
     * @param id 资产分类ID
     * @return 资产分类信息
     */
    AssetClassification selectById(Long id);

    /**
     * 新增资产分类
     *
     * @param classification 资产分类信息
     * @return 资产分类信息
     */
    AssetClassification insert(AssetClassification classification);

    /**
     * 修改资产分类
     *
     * @param classification 资产分类信息
     * @return 资产分类信息
     */
    AssetClassification update(AssetClassification classification);

    /**
     * 更新资产分类状态
     *
     * @param id            资产分类ID
     * @param status        状态
     * @param lastModUserId 最后修改人ID
     * @return 是否成功
     */
    boolean updateStatus(Long id, String status, String lastModUserId);

    /**
     * 删除资产分类
     *
     * @param id            资产分类ID
     * @param lastModUserId 最后修改人ID
     */
    void deleteById(Long id, String lastModUserId);

    /**
     * 批量删除资产分类
     *
     * @param ids           需要删除的数据ID集合
     * @param lastModUserId 最后修改人ID
     */
    void deleteBatchIds(List<Long> ids, String lastModUserId);

    /**
     * 校验资产分类编码是否唯一
     *
     * @param classification 资产分类信息
     * @return 结果
     */
    boolean checkCodeUnique(AssetClassification classification);

    /**
     * 根据分类名称查询分类ID
     *
     * @param classificationName 分类名称
     * @return 分类ID
     */
    Long selectIdByName(String classificationName);

    /**
     * 检查分类名称是否存在
     *
     * @return 是否存在
     */
    boolean checkClassificationNameExists(AssetClassification assetClassification);
}