package com.psbc.cpsp.eden.service.asset;

import com.psbc.cpsp.eden.common.entity.AssetLabel;
import com.psbc.cpsp.eden.common.response.AssetResult;
import java.util.List;

/**
 * 资产标签Service接口
 */
public interface IAssetLabelService {
    /**
     * 查询资产标签列表
     *
     * @param label 资产标签信息
     * @return 资产标签集合
     */
    List<AssetLabel> selectList(AssetLabel label);

    /**
     * 根据ID查询资产标签
     *
     * @param id 资产标签ID
     * @return 资产标签信息
     */
    AssetLabel selectById(Long id);

    /**
     * 新增资产标签
     *
     * @param label 资产标签信息
     * @return 资产标签信息
     */
    AssetLabel insert(AssetLabel label);

    /**
     * 修改资产标签
     *
     * @param label 资产标签信息
     * @return 资产标签信息
     */
    AssetLabel update(AssetLabel label);

    /**
     * 删除资产标签
     *
     * @param id            资产标签ID
     * @param lastModUserId 最后修改人ID
     */
    void deleteById(Long id, String lastModUserId);

    /**
     * 批量删除资产标签
     *
     * @param ids           需要删除的数据ID集合
     * @param lastModUserId 最后修改人ID
     */
    void deleteBatchIds(List<Long> ids, String lastModUserId);

    /**
     * 验证资产标签数据
     * 
     * @param label 资产标签对象
     * @return 验证结果
     */
    AssetResult<AssetLabel> validateAssetLabel(AssetLabel label);

    /**
     * 根据租户ID查询资产标签
     *
     * @return 资产标签对象
     */
    AssetLabel selectByAll();
}