package com.psbc.cpsp.eden.service.asset;

import com.psbc.cpsp.eden.common.entity.Asset;
import com.psbc.cpsp.eden.common.vo.AssetExportVO;
import java.util.List;

/**
 * 资产Service接口
 */
public interface IAssetService {
    /**
     * 查询资产列表
     *
     * @param asset 资产信息
     * @return 资产集合
     */
    List<Asset> selectList(Asset asset);

    /**
     * 根据ID查询资产
     *
     * @param id 资产ID
     * @return 资产信息
     */
    Asset selectById(Long id);

    /**
     * 新增资产
     *
     * @param asset 资产信息
     * @return 资产信息
     */
    Asset insert(Asset asset);

    /**
     * 修改资产
     *
     * @param asset 资产信息
     * @return 资产信息
     */
    Asset update(Asset asset);

    /**
     * 更新资产状态
     *
     * @param id            资产ID
     * @param status        状态
     * @param lastModUserId 最后修改人ID
     * @return 是否成功
     */
    boolean updateStatus(Long id, String status, String lastModUserId);

    /**
     * 删除资产
     *
     * @param id            资产ID
     * @param lastModUserId 最后修改人ID
     */
    void deleteById(Long id, String lastModUserId);

    /**
     * 批量删除资产
     *
     * @param ids           需要删除的数据ID集合
     * @param lastModUserId 最后修改人ID
     */
    void deleteBatchIds(List<Long> ids, String lastModUserId);

    /**
     * 校验资产编码是否唯一
     *
     * @param asset 资产信息
     * @return 结果
     */
    boolean checkCodeUnique(Asset asset);

    /**
     * 导入资产数据
     *
     * @param assetList     资产数据列表
     * @param updateSupport 是否更新支持，如果已存在，是否更新
     * @param operName      操作人
     * @return 结果消息
     */
    String importAsset(List<Asset> assetList, boolean updateSupport, String operName);

    /**
     * 导出资产数据
     *
     * @param asset 查询条件
     * @return 资产导出数据列表
     */
    List<AssetExportVO> exportAsset(Asset asset);

    /**
     * 根据资产编码查询资产
     *
     * @param assetCode 资产编码
     * @return 资产信息
     */
    Asset selectByCode(String assetCode);

    /**
     * 获取资产管理员名称
     *
     * @param asset 资产信息
     * @return 管理员名称
     */
    String getAssetAdminName(Asset asset);

    /**
     * 获取资产所属公司名称
     *
     * @param asset 资产信息
     * @return 公司名称
     */
    String getAssetCompanyName(Asset asset);
}