package com.psbc.cpsp.entity;

import com.baomidou.mybatisplus.core.metadata.IPage;
import com.psbc.cpsp.entity.enums.BaseRespCodeEnum;
import com.psbc.cpsp.entity.enums.BaseRespCodeInterFace;
import lombok.AllArgsConstructor;
import lombok.Data;
import lombok.NoArgsConstructor;

/**
 * 智慧园区统一响应实体类
 *
 * @param <T>
 */
@Data
@AllArgsConstructor
@NoArgsConstructor
public class CpspReponse<T> {
    private String code;
    private String message;
    private T data;

    public CpspReponse(BaseRespCodeInterFace respCodeEnum, T data) {
        this.code = respCodeEnum.getCode();
        this.message = respCodeEnum.getDesc();
        this.data = data;
    }

    public CpspReponse(BaseRespCodeInterFace respCodeEnum) {
        this.code = respCodeEnum.getCode();
        this.message = respCodeEnum.getDesc();
    }


    public boolean isSuccess() {
        return BaseRespCodeEnum.SUCCESS.getCode().equals(this.getCode());
    }

    public static <T> CpspReponse<T> ok(T t) {
        return new CpspReponse<>(BaseRespCodeEnum.SUCCESS, t);
    }

    public static <T> CpspReponse<T> ok(BaseRespCodeInterFace respCodeEnum, T t) {
        return new CpspReponse<>(respCodeEnum, t);
    }

    public static CpspReponse ok() {
        return new CpspReponse(BaseRespCodeEnum.SUCCESS);
    }

    public static <T> CpspReponse<PageInfo<T>> ok(IPage<T> pageData) {
        return CpspReponse.ok(PageInfo.toPageInfo(pageData));
    }

    /**
     * 返回错误响应（带数据）
     *
     * @param code    错误码
     * @param message 错误信息
     * @param data    数据
     * @return 响应对象
     */
    public static <T> CpspReponse<T> error(String code, String message, T data) {
        return new CpspReponse<>(code, message, data);
    }

    /**
     * 返回错误响应（不带数据）
     *
     * @param code    错误码
     * @param message 错误信息
     * @return 响应对象
     */
    public static <T> CpspReponse<T> error(String code, String message) {
        return new CpspReponse<>(code, message, null);
    }

    /**
     * 返回错误响应（使用错误码枚举）
     *
     * @param respCodeEnum 错误码枚举
     * @return 响应对象
     */
    public static <T> CpspReponse<T> error(BaseRespCodeInterFace respCodeEnum) {
        return new CpspReponse<>(respCodeEnum);
    }

    /**
     * 返回错误响应（使用错误码枚举和数据）
     *
     * @param respCodeEnum 错误码枚举
     * @param data         数据
     * @return 响应对象
     */
    public static <T> CpspReponse<T> error(BaseRespCodeInterFace respCodeEnum, T data) {
        return new CpspReponse<>(respCodeEnum, data);
    }
}
